@@ -20,6 +20,8 @@ class Simput(AbstractElement):
     :param domains_manager: See simput docs |simput_link| for more info
     :param prefix: Constructing a Simput component will set several variables, optionally prefixed by a namespace
     :type prefix:  str | None
+    :param query: String filtering
+    :type query: str
     :param children: The children nested within this element
     :type children:  str | list[trame.html.*] | trame.html.* | None
 
@@ -38,6 +40,7 @@ class Simput(AbstractElement):
         )
         self._attributes["wsClient"] = ':wsClient="wsClient"'
         self._attributes["namespace"] = f'namespace="{ns}"'
+        self._attr_names += ["query"]
 
     @property
     def controller(self):
@@ -59,11 +62,14 @@ class Simput(AbstractElement):
 
         self._simput_helper.reset()
 
-    def push(self, id=None, type=None, **kwargs):
+    def push(self, id=None, type=None, domains=None, proxy=None, **kwargs):
         """
         Ask server to push data, ui, or constraints
         """
-        self._simput_helper.push(id, type)
+        if proxy is not None:
+            id = proxy
+            domains = proxy
+        self._simput_helper.push(id=id, type=type, domains=domains)
 
     def update(self, change_set, **kwargs):
         """
