@@ -1,22 +1,16 @@
 import sys
 import argparse
 import json
+import os
 
 # ----------------------------------------
 # Helpers
 # ----------------------------------------
+script_dir = os.path.dirname(__file__)
+with open(os.path.join(script_dir, "./header.py")) as header:
+    module_header = header.read()
 
-module_header = """
-from trame import get_app_instance
-from trame.html import AbstractElement, Template
-
-# Make sure used module is available
-_app = get_app_instance()
-if "vuetify" not in _app.vue_use:
-    _app.vue_use += ["vuetify"]
-
-
-"""
+tts_sensitive_elements = ["VSelect", "VDataTable"]
 
 
 def get_attributes(tag):
@@ -68,6 +62,53 @@ def get_events(tag):
         ]"""
 
 
+def get_docs(tag):
+    url = tag.get("doc-url", "https://vuetifyjs.com/en/introduction/why-vuetify/")
+    url = url.replace("www.", "")  # www redirects to start page
+
+    name = tag.get("name")
+    attributes = tag.get("attributes", [])
+    params = ""
+    for attribute in attributes:
+        raw_name = attribute.get("name")
+        attribute_name = raw_name.replace("-", "_")
+        attribute_type = attribute.get("value", {}).get("type", "string")
+        description = attribute.get("description")
+        if "](" in description:
+            # Hide descriptions with markdown
+            description = f"See description |{name}_vuetify_link|."
+        params += f"""
+    :param {attribute_name}: {description}
+    :type {attribute_type}:"""
+
+    events = tag.get("events")
+    event_params = ""
+    for event in events:
+        entry = event.get("name")
+        description = event.get("description")
+
+        # Ignore calendar events, AbstractElement events
+        if not "<" in entry and entry not in ["mouseup", "mousedown", "click"]:
+            entry = entry.replace(":", "_").replace("-", "_")
+            event_params += f"\n    :param {entry}: {description}"
+
+    if len(event_params):
+        event_params = "\n    Events\n" + event_params
+
+    return f"""
+    \"\"\"
+    Vuetify's {name} component. See more info and examples |{name}_vuetify_link|.
+
+    .. |{name}_vuetify_link| raw:: html
+
+        <a href="{url}" target="_blank">here</a>
+
+    {params}
+    {event_params}
+    \"\"\"
+    """
+
+
 def expand_parenthetical(attribute, attributes):
     sizes = ["sm", "md", "lg", "xl"]
     numbers = list(range(13)) if "0" in attribute else list(range(1, 13))
@@ -121,13 +162,18 @@ def generate_vuetify(input_file, output_file):
         tag_name = tag.get("doc-url").replace("https://www.vuetifyjs.com/api/", "")
         attributes = get_attributes(tag)
         events = get_events(tag)
+        docs = get_docs(tag)
         for slot in tag.get("slots", []):
             slots_names.add(slot.get("name"))
 
         class_def = f"""
 class {name}(AbstractElement):
-    def __init__(self, __content=None, **kwargs):
-        super().__init__("{tag_name}", __content, **kwargs)"""
+    {docs}
+    def __init__(self, children=None, **kwargs):
+        super().__init__("{tag_name}", children, **kwargs)"""
+
+        if name in tts_sensitive_elements:
+            class_def += "\n        self.ttsSensitive()"
 
         if attributes is not None:
             class_def += attributes
@@ -161,7 +207,7 @@ class {name}(AbstractElement):
 def init_argparse():
     parser = argparse.ArgumentParser(
         usage="%(prog)s [OPTION] [FILE]",
-        description="Generate vuetify module for Trame",
+        description="Generate vuetify module for trame",
     )
     parser.add_argument("-i", "--input", required=True)
     parser.add_argument("-o", "--output")
